#!/usr/bin/env python
import os
import sys

from setuptools import setup, find_packages

if sys.version_info < (3, 6):
    raise NotImplementedError(
        """Nextcode SDK does not support Python versions older than 3.6"""
    )

root_dir = 'nextcodecli'


def get_version_string():
    with open(os.path.join(root_dir, 'VERSION')) as version_file:
        return version_file.readlines()[0].strip()


version = get_version_string()
if 'SETUP_BRANCH' in os.environ:
    version += "-%s" % os.environ['SETUP_BRANCH']

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='nextcode-cli',
    python_requires=">=3.6",
    version=version,
    description="WuXi Nextcode commandline utilities",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='WUXI NextCODE',
    author_email='support@wuxinextcode.com',
    url='https://www.wuxinextcode.com',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    package_data={'nextcodecli': ['VERSION', 'PUBLIC_KEY']},
    install_requires=[
        'boto3',
        'click',
        'python-dateutil==2.8.0',
        'PyYAML',
        'requests',
        'tabulate',
        'hjson',
        'PyJWT==1.7.1',
        'configparser',
        'future',
        'jsonpath_rw',
        'simplejson',
        'nextcode-sdk>=1.16.1',
    ],
    entry_points={
        'console_scripts': [
            'nextcode = nextcodecli.__main__:cli',
        ]
    },
)



#!/usr/bin/env python

import click

import logging

import sys
import json
from jsonpath_rw import parse
import yaml
import dateutil

log_formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')

console_handler = logging.StreamHandler()
console_handler.setFormatter(log_formatter)
console_handler.setLevel(logging.WARN)

root_logger = logging.getLogger()
root_logger.setLevel(logging.DEBUG)
root_logger.addHandler(console_handler)


def print_error(*txt):
    color_print(*txt, color='red')


def print_warn(*txt):
    color_print(*txt, color='yellow')


def print_success(*txt):
    color_print(*txt, color='green')


def color_print(*args, **kwargs):
    color = kwargs.get('color', 'reset')
    for x in args:
        click.echo(click.style(x, fg=color))


def print_tab(key, val):
    from builtins import str  # py2 backwards compatibility

    val = click.style(str(val), bold=True)
    click.echo("{0:20}{1}".format(key, val))


def print_table(obj):
    try:
        for k, v in obj.items():
            print_tab(k, v)
    except Exception:
        click.echo(obj)


def dumps(obj):
    try:
        return json.dumps(obj, indent=4, sort_keys=True)
    except Exception:
        return repr(obj)


def output_pretty_json(dct, keys):
    ret = ""
    for k in keys:
        jsonpath_expr = parse(k)
        ret = [match.value for match in jsonpath_expr.find(dct)]
        lst = ['']
        if ret:
            if isinstance(ret[0], list) or isinstance(ret[0], dict):
                lst = yaml.dump(ret[0]).split('\n')
            else:
                lst = [str(ret[0])]
        print_tab(k.split('.')[-1], lst[0])
        if len(lst) > 1:
            for v in lst[1:]:
                print_tab("", v)


def get_logger(name='nextcodecli', level=None):
    # TODO - refactor this funtion away - it's useless
    return logging.getLogger(name)


def abort(reason, code=1):
    """
    exit with non-zero exit code and write reason for error to stderr.
    If we are outside a click context and exception will be raised instead
    """
    click.echo(click.style(str(reason), fg='red'), file=sys.stderr)
    ctx_test = click.get_current_context(silent=True)
    if ctx_test:
        sys.exit(code)
    else:
        raise Exception("Abnormal Termination")


def check_profile(ctx):
    if not ctx.obj.client:
        abort(
            "You have no active profile or selected profile is invalid. Run 'nextcode profile add [name]'"
        )


def fmt_date(dt):
    return dateutil.parser.parse(dt).strftime("%Y-%m-%d %H:%M")
